@@ -45,7 +45,7 @@ from kiwi.ui.delegates import SlaveDelegate
 from kiwi.ui.objectlist import ObjectList, SummaryLabel, SearchColumn
 from kiwi.ui.widgets.combo import ProxyComboBox
 from kiwi.ui.widgets.entry import ProxyDateEntry
-from kiwi.utils import gsignal, gproperty
+from kiwi.utils import gsignal
 
 _ = lambda m: gettext.dgettext('kiwi', m)
 
@@ -217,8 +217,8 @@ class SearchFilter(gtk.HBox):
     """
     A base classed used by common search filters
     """
-    gproperty('label', str, flags=(gobject.PARAM_READWRITE |
-                                   gobject.PARAM_CONSTRUCT_ONLY))
+    label = gobject.property(type=str, flags=(gobject.PARAM_READWRITE |
+                                              gobject.PARAM_CONSTRUCT_ONLY))
     gsignal('changed')
     gsignal('removed')
 
@@ -740,6 +740,7 @@ class NumberSearchFilter(SearchFilter):
 
     def __init__(self, label=''):
         """
+        Create a new NumberSearchFilter object.
         @param label: name of the search filter
         """
 
@@ -757,7 +758,6 @@ class NumberSearchFilter(SearchFilter):
         self.mode.show()
 
         self.start = gtk.SpinButton(climb_rate=1.0)
-        self.start.set_digits(2)
         self.start.get_adjustment().step_increment = 1.0
         self.start.set_range(-sys.maxint-1, sys.maxint)
         self.pack_start(self.start, False, False, 6)
@@ -780,6 +780,14 @@ class NumberSearchFilter(SearchFilter):
 
         self.mode.select_item_by_position(0)
 
+    def set_digits(self, digits):
+        """
+        Number of decimal place to be displayed
+        @param digits: number of decimal places
+        """
+        self.start.set_digits(digits)
+        self.end.set_digits(digits)
+
     #
     #   Private
     #
@@ -902,7 +910,9 @@ class SearchContainer(gtk.VBox):
     of bottom, see L{SearchFilterPosition}
     """
     __gtype_name__ = 'SearchContainer'
-    gproperty('filter-label', str)
+    filter_label = gobject.property(type=str)
+    results_class = SearchResults
+    gsignal("search-completed", object)
 
     def __init__(self, columns=None, chars=25):
         """
@@ -1082,8 +1092,8 @@ class SearchContainer(gtk.VBox):
             raise ValueError("A query executer needs to be set at this point")
         states = [(sf.get_state()) for sf in self._search_filters]
         results = self._query_executer.search(states)
-        self.results.clear()
-        self.results.extend(results)
+        self.add_results(results)
+        self.emit("search-completed", self.results)
         if self._summary_label:
             self._summary_label.update_total()
 
@@ -1141,6 +1151,10 @@ class SearchContainer(gtk.VBox):
     def enable_advanced_search(self):
         self._create_advanced_search()
 
+    def add_results(self, results):
+        self.results.clear()
+        self.results.extend(results)
+
     #
     # Callbacks
     #
@@ -1165,7 +1179,7 @@ class SearchContainer(gtk.VBox):
     def _create_ui(self):
         self._create_basic_search()
 
-        self.results = SearchResults(self._columns)
+        self.results = self.results_class(self._columns)
         self.pack_end(self.results, True, True, 6)
         self.results.show()
 
@@ -1256,6 +1270,8 @@ class SearchContainer(gtk.VBox):
               column.data_type == int or
               column.data_type == currency):
             filter = NumberSearchFilter(title)
+            if column.data_type != int:
+                filter.set_digits(2)
         elif column.data_type == str:
             if column.valid_values:
                 filter = ComboSearchFilter(title, column.valid_values)
@@ -1278,14 +1294,11 @@ class SearchContainer(gtk.VBox):
             self.combo_group.add_widget(combo)
 
 
-# This is not quite a requirement at this point, only
-# do it if install_child_property is available, eg pygtk >= 2.10
-if hasattr(gtk.Container, 'install_child_property'):
-    SearchContainer.install_child_property(
-        1, ('filter-position', str,
-            'Search Filter Position',
-            'The search filter position in the container',
-            '', gobject.PARAM_READWRITE))
+SearchContainer.install_child_property(
+    1, ('filter-position', str,
+        'Search Filter Position',
+        'The search filter position in the container',
+        '', gobject.PARAM_READWRITE))
 
 
 class SearchSlaveDelegate(SlaveDelegate):
